# OKING - OkVendas
Sistema python para realizar a integração entre ERP's e a solução OkVendas da Openk.

Dentre os módulos de integração estão:
- Preço
- Estoque
- Pedido
- Produtos

### Automação
- Windows (Task Scheduler)
  - Utilizar o arquivo XML fornecido no link abaixo para criar uma nova tarefo no Agendador de tarefas do Windows. Com a tarefa criada, o Oking iniciará a integração automaticamente.
- Linux (Crontab)
  - Disponível em breve.